# CLI リファレンス

## 主なコマンド

- ZXQコード0ZXQ
- `vyro dev --app <module:attr>`
- `vyro doctor [--strict]`
- `vyro openapi ...`
- ZXQコード4ZXQ
- `vyro release ...`

## 終了コード

- `0`: 成功
- `1`: 実行/ツール/ランタイム エラー
- `2`: 検証/使用エラー